.. _{{ fullname }}:


.. raw:: html

    <br>
    <center>
    <h3>
    <b>

.. title:: {{ fullname }}


:ref:`src <source>`/**{{ name }}**

.. raw:: html

    </b><h3></center>

.. auto{{ objtype }}:: {{ fullname }}
    :members:
    :private-members:
    :undoc-members:

.. raw:: html

    <br><br>

'''
